@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0104';
 
 use strict;
 use warnings;
@@ -106,7 +106,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0103
+version 0.0104
 
 =head1 SYNOPSIS
 
@@ -124,19 +124,9 @@ version 0.0103
 C<MIDI::Chord::Guitar> provides MIDI pitches for common chord voicings
 of an C<E A D G B E> tuned guitar.
 
-=begin html
-
-Here is a handy diagram of MIDI pitch numbers laid out on a guitar neck:
-<br>
-<img src="https://raw.githubusercontent.com/ology/MIDI-Chord-Guitar/main/guitar-position-midi-numbers.png">
-<br>
-
-And here is a diagram of MIDI pitch octaves laid out on a guitar neck:
+=for html <p>Here is a handy diagram of MIDI pitch octaves laid out on a guitar neck:</p>
 <br>
 <img src="https://raw.githubusercontent.com/ology/MIDI-Chord-Guitar/main/guitar-position-midi-octaves.png">
-<br>
-
-=end html
 
 =head1 ATTRIBUTES
 
@@ -146,6 +136,39 @@ And here is a diagram of MIDI pitch octaves laid out on a guitar neck:
 
 Computed attribute available after construction.
 
+The chord names are given to the module methods as the B<chord_name>.
+They are as follows:
+
+  '' (major)
+  aug
+  dim
+  dim7
+  m (minor)
+  m11
+  m6
+  m7
+  m7b5
+  m7b5#9
+  m9
+  maj7
+  maj7#11
+  maj9
+  sus2
+  sus4
+  6
+  6(9)
+  7
+  7#5
+  7#9
+  7b13
+  7b5
+  7b9
+  7b9b13
+  9
+  9sus4
+  11
+  13
+
 =head1 METHODS
 
 =head2 as_file
